<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * Base Command
 */
require_once 'BaseCommandUser.php';

/**
 * User domain object
 */
require_once 'PHPARCH/Account.php';

/**
 * PEAR's Exception class
 */
require_once 'PEAR/Exception.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Login command
 *
 * @copyright 2005
 * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
 *
 */
class PHPARCH_DeleteAccountCommand extends PHPARCH_BaseCommandUser {
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToView()
    {
        if (!$this->user->getIsAdmin()) {
            return false;
        }
        return false;
    }
    
    /**
     * Deletes an account
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    public function execute()
	{
	    if (empty($_POST['yes']) AND empty($_POST['no'])) {
	        throw new Exception('You must confirm you want to delete the account before the action
	           will be taken');
	    }
	    
	    // Ensure the user didn't hit the cancel button.  If they did bail.
	    if (!empty($_POST['no'])) return 'cancel';

	    if (empty($_POST['aid'])) {	
		    throw new Exception('No account was given to the Delete Account Command');
		}
		
		// Load matching user record from the database.
		$dao = PHPARCH_DAO::singleton();
				
		try {
		  $retVal = $dao->deleteWithCondition('deleteAccount', array($_POST['aid']));
		} catch (Exception $e) {
		    // Throw the exception back for now, this really should be handled here
		    throw $e;
		}

		// Send a message back to the user letting them know the delete worked fine. 
		$_SESSION['MVC_MESSAGES'][] = 'Account successfully deleted!'; 
		
		// go to home page
		return 'success';
	}
}

?>