<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * Base Command
 */
require_once 'BaseCommandUser.php';

/**
 * User domain object
 */
require_once 'PHPARCH/Contact.php';

/**
 * PEAR's Exception class
 */
require_once 'PEAR/Exception.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Login command
 *
 * @copyright 2005
 * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
 *
 */
class PHPARCH_DeleteContactCommand extends PHPARCH_BaseCommandUser {
    private $contact = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToRun()
    {
        // The confirmation page has already put the contact to delete in the request.  Verify it
        // one more time.
        // Load the contact
        $dao = PHPARCH_DAO::singleton();
        $this->contact = new Contact();
        $this->contact->setContactId($_POST['cid']);
        $this->contact = $dao->get($this->contact);
        
        // Make sure we got a valid contact object back.
        if (!is_object($this->contact)) {
            throw new Exception('The contact cannot be deleted because it does not exist');
        }
        
        // Ensure the contact requested is tied to the user making the request.
        if ($this->contact->getAccountId() == $this->user->getAccountId()) {
            return true;
        }
        
        return false;
    }
    
    /**
     * Deletes a contact
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    public function execute()
	{
	    if (empty($_POST['yes']) AND empty($_POST['no'])) {
	        throw new Exception('You must confirm you want to delete the contact before the action
	           will be taken');
	    }
	    
	    // Ensure the user didn't hit the cancel button.  If they did bail.
	    if (!empty($_POST['no'])) return 'cancel';

	    // Load matching user record from the database.
		$dao = PHPARCH_DAO::singleton();
				
		try {
		  $dao->beginTransaction();
		  $wAddress = $this->contact->getAddressRelatedByWorkAddressId();
		  $hAddress = $this->contact->getAddressRelatedByHomeAddressId();
		  $dao->delete($this->contact);
		  $dao->delete($wAddress);
		  $dao->delete($hAddress);
		  $dao->commit();		  
		} catch (Exception $e) {
		    $dao->rollbackTransaction();
		    // Throw the exception back for now, this really should be handled here
		    throw $e;
		}

		// Send a message back to the user letting them know the delete worked fine. 
		$_SESSION['MVC_MESSAGES'][] = 'Contact successfully deleted!'; 
		
		// go to home page
		return 'success';
	}
}

?>