<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * DVRS Improving Transition Outcomes
 *
 * License Details To Be Determined
 *
 */
  
/**
 * Base Command
 */
require_once 'BaseCommand.php';

/**
 * User domain object
 */
require_once 'PHPARCH/Account.php';

/**
 * PEAR's Exception class
 */
require_once 'PEAR/Exception.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Login command
 *
 * @copyright 2005 Iowa Department of Vocational and Rehabilitation Services
 * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
 * @todo Add better error handling
 *
 */
class PHPARCH_LoginCommand extends PHPARCH_BaseCommand {
    /**
     * Logs a user in
     *
     * Uses ITE's Enterprise Authentication and Authorization (A&A) Service to authenticate a user
     * and load the associated privileges in the system.
     *
     * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
     * @access public
     * 
     */
	public function execute()
	{
		global $conf;		
						
		// Load matching user record from the database.
		$dao = PHPARCH_DAO::singleton();
		
		$retVal = $dao->find('getUserByUserName', array($_POST['username']));
		        
		// If no matching user was found, give a friendly error message.
		if (count($retVal) == 0) {
		    throw new Exception('No account within the PHPARCH Contact Manager system matches your user name. 
                You have not been given access to this system yet');
		} else {
		    $user = $retVal[0];
		}

		// Make sure the account is enabled.	
		if (!$user->getIsEnabled()) {
		    throw new Exception('This account has been disabled.  Please contact the system 
		      administrator if you feel this is an error');
		}
		
		// Save user object to session
		$_SESSION['user'] = serialize($user);
		
		// go to home page
		return 'goHome';
	}
}

?>