<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * Base Command
 */
require_once 'BaseCommandUser.php';

/**
 * User domain object
 */
require_once 'PHPARCH/Contact.php';

/**
 * PEAR's Exception class
 */
require_once 'PEAR/Exception.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Login command
 *
 * @copyright 2005
 * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
 *
 */
class PHPARCH_SaveContactCommand extends PHPARCH_BaseCommandUser {
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToRun()
    {        
        // We will always have a contact in session, question will be whether or not it is new.
		$this->contact = unserialize($_SESSION['contact']);

		if (is_object($this->contact)) {
		    if ($this->contact->getAccountId()) {
		        if ($this->contact->getAccountId() <> $this->user->getAccountId()) {
		            return false;
		        }
		    } 
		}
		return true;
    }
    
    /**
     * Saves a contact.
     *
     * Uses Propel and the DAO to presist an object back to the database.
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    public function execute()
	{
	    if (empty($this->contact)) {
	        $this->contact = new Contact();
	    }
	    
	    // Try getting the contact ID
		$cid = $this->contact->getContactId();
		
		if (empty($cid)) {		    
		    // This is a new contact, go get the data from the submitted form
		    $objs = $this->requestToObjects(array('Contact'=>$this->contact));
		    
		    // Associate contact to user
		    $objs['Contact']->setAccountId($this->user->getAccountId());
		} else {		
		    // This is an existing contact, let's get the updates from the form
    		$objs = $this->requestToObjects(
                array('Contact'=>$this->contact, 
                      'Address_Home'=>$this->contact->getAddressRelatedByHomeAddressId(), 
                      'Address_Work'=>$this->contact->getAddressRelatedByWorkAddressId()));
		}
          
		// Until requestToObjects can handle parent child references we have to do this
		$this->contact = $objs['Contact'];  
		// NOTE: there is not point in creating address records if we didn't get any data in them.
		// the following will check to see if they are empty and, if not, set the address properly.     
		if (!$objs['Address_Home']->isEmpty()) {
		    $this->contact->setAddressRelatedByHomeAddressId($objs['Address_Home']);
		}
		if (!$objs['Address_Work']->isEmpty()) {
		    $this->contact->setAddressRelatedByWorkAddressId($objs['Address_Work']);
		}
		
		// Now let's validate the data
		//$this->passesValidation()
				
		// Load matching user record from the database.
		$dao = PHPARCH_DAO::singleton();
				
		try {
		  // Try saving.  NOTE: this one command will start a transaction, do an insert on the two
		  // address objects and then insert the contact before commiting to the database.
		  $retVal = $dao->save($this->contact);
		} catch (Exception $e) {
		    unset($_SESSION['contact']);
		    // Throw the exception back for now, this really should be handled here
		    throw $e;
		}
		        
		// Now that they are done with the object, remove it from session.
		unset($_SESSION['contact']);
        		
		// Send a message back to the user letting them know the save worked fine. 
		$_SESSION['MVC_MESSAGES'][] = 'Contact successfully saved!';
		
		// go to home page
		return 'success';
	}
}

?>