<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * DVRS Improving Transition Outcommes.
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright State of Iowa 2005
 * @version $Id: DAO.php,v 1.3 2005/03/22 14:15:04 tbibbs Exp $
 *
 */
class PHPARCH_DAO {
    /**
     * Builds an instance of requested DAO object
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param array $options Override default DAO options by passing them here
     * @return ITO_PropelDAO Only DAO implementation at this time
     * @see ITO_DAO::singleton
     *
     */
	public static function &factory($options = '')
	{
		global $conf;
				
		if (empty($options)) {
		    $options = $conf['dao_options'];
		}
		
		$fileToInclude = $conf['path_system'] . 'DataAccess/' . $conf['dao_options']['dao_name'] . '.php';
		
		if (include_once($fileToInclude)) {
			$nameOfClass = 'PHPARCH_' . $conf['dao_options']['dao_name'];
            return new $nameOfClass($options);
        }
	}
	
	/**
     * Grabs a single instance of requested DAO object. 
     *
     * This differs from factory method above in that this will not create a new instance of a DAO 
     * object unless the configuration options differ.  Generally, this method should be used over
     * singleton
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param array $options Override default DAO options by passing them here
     * @return ITO_PropelDAO Only DAO implementation at this time
     * @see ITO_DAO::factory
     *
     */
	public static function &singleton($options = '')
	{
		global $conf;
		
		static $instances;
		
		if (empty($options)) {
		    $options = $conf['dao_options'];
		}
		
        if (!isset($instances)) {
            $instances = array();
        }
        
        $hash = serialize($options);
        if (!isset($instances[$hash])) {
            $instances[$hash] = &self::factory($options);
        }

        return $instances[$hash];
	}
}

?>