<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Generic class that does basic string formatting and unformatting
 *
 */
class PHPARCH_Formatter {
    /**
     * Format's a phone number
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param string $phoneNumber An unformatted phone number
     * @return string A formatted phone number
     *
     */
    static public function formatPhoneNumber($phoneNumber)
    {
        if (empty($phoneNumber)) return;
        
        return sprintf('(%s%s%s)%s%s%s-%s%s%s%s', $phoneNumber[0], $phoneNumber[1], $phoneNumber[2],
	       $phoneNumber[3], $phoneNumber[4], $phoneNumber[5], $phoneNumber[6], $phoneNumber[7],
	       $phoneNumber[8], $phoneNumber[9]);
    }
    
    /**
     * Strips formatting from a phone number
     * 
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param string $phoneNumber A formatted phone number
     * @return string An unformatted phone number
     *
     */
    static public function unformatPhoneNumber($phoneNumber)
    {        
        $phoneNumber = str_replace('(','',$phoneNumber);
        $phoneNumber = str_replace(')','',$phoneNumber);
        $phoneNumber = str_replace(' ','',$phoneNumber);
        $phoneNumber = str_replace('-','',$phoneNumber);
        $phoneNumber = str_replace('.','',$phoneNumber);
        return $phoneNumber;
    }
    
    /**
     * Format's a zip code
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param string $zipCode An unformatted zip code
     * @return string A formatted zip code
     *
     */
    static public function formatZipCode($zipCode)
    {
        if (strlen($zipCode) == 5) return $zipCode;
        
        if (empty($zipCode)) return;
        return sprintf('%s-%s',substr($zipCode, 0, 5), substr($zipCode, 5));
    }
    
    /**
     * Strips formatting from a zip code
     * 
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @static 
     * @param string $zipCode A formatted zip code
     * @return string An unformatted zip code
     *
     */
    static public function unformatZipCode($zipCode)
    {
        $zipCode = str_replace(' ','',$zipCode);
        $zipCode = str_replace('-','',$zipCode);
        return $zipCode;
    }
    
   	/**
	 * Function used from within Flexy templates to show specialized features to users.  
	 * 
	 * Because templates can be shared between this and BaseViewFlexyUser, we are stubbing this out
	 * to always return false
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $objToUse Object reference that has the attribute value to be formatted
	 * @param string $attributeToFormat attribute of the above object 
	 * @return string formatted string.
	 *
	 */
	
	public function formatSqlDateToMonthYear($datestring) {
        if (!empty($datestring) && $datestring != '') {
           $datePieces = explode('-',$datestring);   
            return $datePieces[1].'/'.$datePieces[0];
        } else {
           return '';
        }
	}

	/**
	 * Function used from within Flexy templates to show specialized features to users.  
	 * 
	 * It takes the string whose format is in MM/YYYY and converts it to sql date for saving into database.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $objToUse Object reference that has the attribute value to be formatted
	 * @param string $attributeToFormat attribute of the above object 
	 * @return string formatted string.
	 *
	 */
    	
	public function unFormatMonthYearToSqlDate($mmyyyyFormat,$fieldName='') 
	{
        $fullDateString = null;
        if (empty($mmyyyyFormat)) {
           return '';   
        }
        $retval = explode('/',$mmyyyyFormat);
        $fullDateString = sprintf('%s/1/%s',$retval[0],$retval[1]);
        return  $fullDateString;
	      
	}
}

?>