<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 */

/**
 * BaseView object
 *
 */
require_once 'Geeklog/MVCnPHP/BaseView.php';

/**
 * Bring in translation library
 */
require_once 'Translation2.php';

/**
 * PEAR::HTML_Template_Flexy HTML Template Library
 */
require_once 'HTML/Template/Flexy.php';

/**
 * PEAR::HTML_Template_Flexy_Element
 */
require_once 'HTML/Template/Flexy/Element.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * This class extends the MVCnPHP Base View by adding implementing support
 * for PEAR::HTML_Template_Flexy
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
abstract class PHPARCH_BaseViewFlexy extends MVCnPHP_BaseView {	
    /**
     * base URL to be used by flexy
     *
     * @access public
     * @var string
     */
    public $baseUrl = '';
    
    /**
    * Array of flexy options
    *
    * @access private
    * @var array
    */
    private $options = null;
    
    /**
    * Title of this view
    *
    * @access protected
    * @var string
    */
    public $pageTitle = null;
    
    /**
    * Indicates if we should show navigation or not
    *
    * @access public
    * @var boolean
    */
    public $showNavigation = true;
    
    /**
    * Meta tags to put in the HTML <head> section
    *
    * @access private
    * @var string
    */
    public $metaTags = null;
    
    /**
    * Indicates if user is an administrator
    * @access protected
    * @var boolean
    */
    protected $isAdmin = null;
    
    /**
    * Handle to instance of a flexy object
    *
    * @access protected
    * @var object
    */
    protected $flexyHandle = null;
    
    /**
    * PEAR::HTML_Template_Flexy form elements
    *
    * @access public
    * @var Array
    */
    public $flexyElements = null;
    
    
    /**
    * Holds any messages that may want to be sent back to the user.  Do not use this for error 
    * messages.  That's what $errorMessages is for (see getErrors).
    *
    * @access protected
    * @var array
    */
    public $mvcMessages = null;
    
    /**
     * Holds any error messages recently generated. This is typically accessed by Flexy
     *
     * @var string
     * @access public
     */
    public $errorMessages = null;
     
    /**
    * Initializes PEAR::HTML_Template_Flexy
    *
    * Sets the config optiosn for Flexy and then creates an instance of Flexy that is then
    * available to all descendants
    *
    * @author Tony Bibbs <tony@geeklog.net>
    * @access protected
    *
    */
    protected function initializeFlexy()
    {
    	global $conf;
        
        // Add base URL to variable that can be used by flexy
        $this->baseUrl = $conf['site_url'];
        
        $this->showNavigation = true;
        $this->options = array(
            'templateDir'   => $conf['path_templates'],
            'compileDir'    => $conf['path_templates'] . 'compiled_templates',
            'forceCompile'  => 0,
            'debug'         => 0,
            'locale'        => $lang,
            //'compiler'      => 'Standard',
            'Translation2'  => array('driver' => 'XML', array('filename'=>'il8nxml','save_on_shutdown'=>true)) 
        );
           
        $this->flexyHandle = new HTML_Template_Flexy($this->options);
    }
    
    /**
	* Sets the title for the HTML page being outputted
	*
	* @author Tony Bibs <tony@geeklog.net
	* @access public
	* @param string $pageTitle Title to give the page
	* 
	*/
	public function setPageTitle($pageTitle)
	{
		$this->pageTitle = $pageTitle;
	}
	
	/**
	* Sets the keywords meta tags for the page
	*
	* @author Tony Bibs <tony@geeklog.net
	* @access public
	* @param string $metaTags Meta tags to assign to page
	* 
	*/
	public function setMetaTags($metaTags)
    {
    	$this->metaTags = $metaTags;
    }
    
    /**
	* Returns the page title
	*
	* @author Tony Bibbs <tony@geeklog.net>
	* @access public
	* @return boolean
	*
	*/
	public function getPageTitle()
	{
	    return $this->pageTitle;
	}

    /**
    * Returns the meta tags to show in the page
    *
    * @author Tony Bibbs <tony@geeklog.net>
    * @access public
    * @return boolean
    *
    */
	public function getMetaTags()
	{
	    return $this->metaTags;
	}
	
	/**
	 * This abstract class knows nothing about logged in users so if Flexy asks if we have one
	 * tell it no
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @return boolean Always false
	 *
	 */
	public function haveUser()
    {
        return false;
    }
    
	/**
	 * Translates a string to the right language
	 *
	 * Uses PEAR::Translation2 to convert an english string to 
	 * the right language
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $stringToTranslate English string to Translate
	 * @return string Translated string
	 *
	 */
	public function translate($stringToTranslate)
	{
		
	}
	
    /**
    * Shows the page header
    *
    * @author Tony Bibbs <tony@geeklog.net>
    * @access private
    * @param string $pageTitle Title of the page
    * @param boolean $showNavigation Indicates if the navigation bar should be displayed
    * @param string $metaTags String of XHTML meta tags specific to this page
    *
    */
    protected function showHeader($showNavigation = true)
    {
        $this->showNavigation = $showNavigation;
    	if (empty($this->pageTitle)) {
    		$this->pageTitle = 'DVRS ITO: Page Not Named';
    	}
    	if (empty($this->metaTags)) {
    		$this->metaTags = '';
    	}
        
    	$this->flexyHandle->compile('Header.thtml');
        $this->flexyHandle->outputObject($this);
    }

    /**
    * Shows the page footer
    *
    * @author TonyBibbs
    * @acces private
    *
    */
    protected function showFooter()
    {
        $this->flexyHandle->compile('Footer.thtml');
        $this->flexyHandle->outputObject($this);
    }
        
    /**
    * Renders the view to the user's browser
    *
    * @author Tony Bibbs <tony@geeklog.net>
    * @access public
    *
    */
	public function getView()
	{
		$this->initializeFlexy();
		return $this->processView();
	}	
	
	/**
	* This is where all the magic happens.  Specifically this is where the view of the view gets 
	* generated.  
	*
	* @author Tony Bibbs <tony@geeklog.net>
	* @access public 
	*
	*/
	abstract public function processView();
	
	/**
	*  Calls a function on an object and returns the result
	*
	*  @author Tony Bibbs <tony@geeklog.net>
	*
	*/	
	public function callOnObject($method, $object) {
	    return call_user_func(array($object, $method));
	}
	
	/**
	*  Calls a function on an array element and returns the result
	*
	*  @author Tony Bibbs <tony@geeklog.net>
	*
	*/	
	public function callOnArray($method, $array, $num) {
	    $object = $array[$num];
	    return call_user_func(array($object, $method));
	}
	
	/**
	* Used by flexy to determine if a <option> tag should be
	* displayed with selected or not
	*
	* @author Tony Bibbs <tony@geeklog.net>
	* @access public
	* @return boolean
	*
	*/
	public function isEqual($key, $value) {
	    if ($key == $value) {
	        return true;
        }
        return false;
	}
		
    /**
    * This short piece of code converts a request into a Propel model objec that the 
    * developer can work directly with.
    *
    * It is possible to map form fields directly to model objects so that the command that catches
    * the request can begin working with the objects immediately and not have to do the form field
    * to domain object mapping themselves.  
    *
    * NOTE: should one of the setters cause an exception to get thrown, we simply ignore them and 
    * continue processing.  This is important because Propel's date/time setters() expect a 
    * format argument that we aren't giving them so we'll just ignore it and let the caller fo this
    * method try and figure out the problem.
    *
    * @author Tony Bibbs <tony@geeklog.net>
    * @access public
    * @return array Array of objects
    *
    */
    protected function requestToObjects()
	{
		$postVars = array_keys($_REQUEST);
		foreach ($postVars as $curVarName) {
			if (stristr($curVarName, '->')) {
				$tmpArray = explode('->',$curVarName);
				$objArray[$tmpArray[0]][$tmpArray[1]] = $_REQUEST[$curVarName];
			}
		}
		$objNames = array_keys($objArray);
		$objInstances = array();
		foreach ($objNames as $curObj) {
			if (empty($objInstances[$curObj])) {
				$obj = new $curObj();
				$objInstances[$curObj] = $obj;
			} else {
				$obj = $objInstances[$curObj];
			}
			$objAttributes = array_keys($objArray[$curObj]);
			foreach ($objAttributes as $curAttribute) {
				$fnName = 'set' . ucwords($curAttribute);
				try {
				    $obj->$fnName($objArray[$curObj][$curAttribute]);
				} catch (Exception $e) {
				    // Just continue going on from here
				}
			}
			$objInstances[$curObj] = $obj;
		}
		return $objInstances;
	}
	
	/**
     * Gets a drop down from the list_item table
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access protected
     * @param string $dropDownName Named query representing the drop down
     * @param string $htmlFieldName Name to give the html select field
     * @param array $queryArgs Any arguments the query may require
     * @param string $setValue Gives the value of the option in the drop down we want to set as
     * the selected item
     * @param string $idAttribute Attribute on object that will serve as the ID field in the option
     * tag
     * @param string $displayAttribute Attribute on object that will be shown in the actual drop
     * down for the option tag
     * @param string $stubText If you want an empty stubbed value pass the text you want shown in 
     * the drop down (i.e. --Select State--)
     *
     */
	protected function getDropDown($dropDownName, $htmlFieldName, $queryArgs = '' , $setValue = ''
		, $idAttribute = '', $displayAttribute = '', $stubText = '')
	{	    
		$resultArray = array();
		$dao = PHPARCH_DAO::singleton();
		if (is_array($queryArgs) AND (count($queryArgs) > 0)) {
			$objArray = $dao->find($dropDownName, $queryArgs);
		} else {
			$objArray = $dao->find($dropDownName);
		}
		$idGetMethod = 'get' . ucwords($idAttribute);
		$displayGetMethod = 'get' . ucwords($displayAttribute);
		if (!empty($stubText)) {
		    // Quotes needed so that the value will be "" instead of 0
		    $resultArray[''] = $stubText;
		}
		foreach ($objArray as $curObj) {
			$resultArray[$curObj->$idGetMethod()] = $curObj->$displayGetMethod();
		}
		$this->flexyElements[$htmlFieldName] = new HTML_Template_Flexy_Element;
    	$this->flexyElements[$htmlFieldName]->setOptions($resultArray);
    	if (!empty($setValue)) {
			$this->flexyElements[$htmlFieldName]->setValue($setValue);
    	}
	}
	
	/**
     * Gets a drop down from a pre-existing array of objects
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access protected
     * @param array $objArray Array of object to put into a drop down.
     * @param string $htmlFieldName Name to give the html select field
     * @param array $queryArgs Any arguments the query may require
     * @param string $setValue Gives the value of the option in the drop down we want to set as
     * the selected item
     * @param string $idAttribute Attribute on object that will serve as the ID field in the option
     * tag
     * @param string $displayAttribute Attribute on object that will be shown in the actual drop
     * down for the option tag
     * @param string $stubText If you want an empty stubbed value pass the text you want shown in 
     * the drop down (i.e. --Select State--)
     *
     */
	protected function getDropDownFromObjects($objArray, $htmlFieldName, $queryArgs = '', 
	   $setValue = '', $idAttribute = '', $displayAttribute = '', $stubText = '')
	{	    
	    if (!is_array($objArray)) {
	        require_once 'PEAR/Exception.php';
	        throw new PEAR_Exception('We did not get an array of objects');
	    }
		$idGetMethod = 'get' . ucwords($idAttribute);
		$displayGetMethod = 'get' . ucwords($displayAttribute);
		if (!empty($stubText)) {
		    $resultArray[] = $stubText;
		}
		foreach ($objArray as $curObj) {
			$resultArray[$curObj->$idGetMethod()] = $curObj->$displayGetMethod();
		}
		$this->flexyElements[$htmlFieldName] = new HTML_Template_Flexy_Element;
    	$this->flexyElements[$htmlFieldName]->setOptions($resultArray);
    	if (!empty($setValue)) {
			$this->flexyElements[$htmlFieldName]->setValue($setValue);
    	}
	}
	
	/**
     * Builds a drop down from an array
     *
     * @author Tony Bibbs tony@geeklog.net
     * @access protected
     * @param array $dataArray Array of data in id->displayValueformat to show in the drop down
     * @param string $htmlFieldName Name to give the html select tag
     * @param string $setValue Gives the value of the option in the drop down we want to set as
     * the selected item
     * @param boolean $useKeyAsValue Indicates if the keys from $dataArray should be used as the 
     * values for the option tags.
     * @param string $stubText If you want an empty stubbed value pass the text you want shown in 
     * the drop down (i.e. --Select State--)
     *
     */
	protected function getDropDownFromArray($dataArray, $htmlFieldName, $setValue='', 
	   $useKeyAsValue = false, $stubText = '')
	{
		$this->flexyElements[$htmlFieldName] = new HTML_Template_Flexy_Element;
		if (!empty($stubText)) {
		    $resultArray[] = $stubText;
		}
		$this->flexyElements[$htmlFieldName]->setOptions($dataArray, !$useKeyAsValue);
		if (!empty($setValue)) {
			$this->flexyElements[$htmlFieldName]->setValue($setValue);
    	}
	}
	
	/**
	 * Binds an object to a form fields 
	 *
	 * NOTE: this framework assumes you will strictly adhere to the form field naming conventions.
	 * If you don't, this method will not work as expected.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @param string $fieldName The form field to bind the object to
	 * @param Object $obj Object to bind to the fields
	 * @see PHPARCH_BaseViewFlexy::bindObjectToField
	 *
	 */
	protected function bindObjectToField($htmlFieldName, $obj)
	{	 
	    // Make sure we got an object, if not, ignore it and try to continue on   
	    if (!is_object($obj)) {
	        return;
	    }
	    $tmpArray = explode('->',$htmlFieldName);
	    if (count($tmpArray) <> 2) {
	        throw new Exception('Field name must be in format: object->fieldName');
	    }
	    $methodToCall = 'get' . ucfirst($tmpArray[1]);
	    
	    $this->flexyElements[$htmlFieldName] = new HTML_Template_Flexy_Element;
	    $this->flexyElements[$htmlFieldName]->setValue($obj->$methodToCall());	    
	}

	/**
	 * Binds an object to a bunch of form fields 
	 *
	 * NOTE: this framework assumes you will strictly adhere to the form field naming conventions.
	 * If you don't, this method will not work as expected.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @param array $fieldNameArray Array of the form fields to bind the object to
	 * @param Object $obj Object to bind to the fields
	 * @see PHPARCH_BaseViewFlexy::bindObjectToField
	 */
	protected function bindObjectToFields($fieldNameArray, $obj)
	{
	    if (!is_array($fieldNameArray)) {
	        throw new Exception('You must give an array of fields to this method');
	    }
	    foreach ($fieldNameArray as $curFieldName) {
	        $this->bindObjectToField($curFieldName, $obj);
	    }
	}
	
	/**
	 * Gets a formatted string with any form validation error messages
	 *
	 * Note, after calling this you can reference {errorMessages:h} in your flexy template to show
	 * your error messages.  You must use the :h for the BR tags to be interpreted properly
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @return string Formatted string with all form validation error messages
	 *
	 */
	public function getErrors()
	{
	    if (!is_array($_SESSION['MVC_ERRORS'])) return;
	    
	    foreach ($_SESSION['MVC_ERRORS'] as $fieldErrors) {
	        $this->errorMessages .= implode("<br/>",$fieldErrors) . "<br/>";	        
	    }
	    
	    // No longer need the messages in the session...free up the memory.
	    unset($_SESSION['MVC_ERRORS']);
	    
        return $this->errorMessages;
	}
	
	/**
	 * Gets a formatted string with any messages that need to be communicated with the user
	 *
	 * Note, after calling this you can reference {mvcMessages:h} in your flexy template to show
	 * your messages.  You must use the :h for the BR tags to be interpreted properly
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @return string Formatted string with all messages
	 *
	 */
	public function getMessages()
	{
	    if (!is_array($_SESSION['MVC_MESSAGES'])) return;
	    
	    $this->mvcMessages .= implode("<br/>",$_SESSION['MVC_MESSAGES']) . "<br/>";	        
	    
	    // No longer need the messages in the session...free up the memory.
	    unset($_SESSION['MVC_MESSAGES']);
	    
        return $this->mvcMessages;
	}
	
	/**
	 * Function used from within Flexy templates to show specialized features to users.  
	 * 
	 * Because templates can be shared between this and BaseViewFlexyUser, we are stubbing this out
	 * to always return false
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $privilegeName Privilege name
	 * @return boolean Always false at this level
	 * @see PHPARCH_BaseViewFlexyUser::hasPrivilege
	 *
	 */
	public function hasPrivilege($privilegeName)
	{
	    return false;
	}
	
	/** 
	* Function used to populate hard-coded lists of fields via flexy
	*
	* @author Tony Bibbs <tony@geeklog.net>
	* @access public
	* @param $objectName Local View Object to use.
	* @param $methodCall Local View Object -> method to call
	* @param $identity Identity
	* @param optional $optCompare Compare Method Return for CHECKED SELECTED status
	*/
	    public function fetchValue($objectName,$methodCall,$identity,$optCompare=''){
    	$object = $this->$objectName;
    	$object = $object[$identity];
    	if(is_object($object)){
    		if(!empty($optCompare)){
    			if(call_user_method($methodCall,$object)==$optCompare){
    			return '" CHECKED="TRUE" SELECTED="TRUE';
    			}
    		} else {
    			return call_user_method($methodCall,$object);
    		}
    	}		
    }
    
    /**
	 * Determines if the current user is an administrator.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @return boolean True if the user is an administrator, otherwise false
	 *
	 */
	public function isAdmin()
	{
	    if (is_object($this->user)) {
	       return $this->user->getIsAdmin();
	    }
	    return false;
	}
}

?>