<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Abstract class that knows how to handle active user sessions
 */
require_once 'BaseViewFlexyUser.php';

/**
 * The Contact domain object
 */
require_once 'PHPARCH/Account.php';

/**
 * Grab the DAO
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Allows an administrator to maintain all look up values stored in the list_item table.
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
class PHPArch_AccountEditorView extends PHPARCH_BaseViewFlexyUser {
    /**
     * Holds the contact the editor is working with.  This is made public so that 
     * flexy can work with it, if necessary.
     * @var Contact
     * @access public
     */
    public $account = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to view a screen
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can view the screen, otherwise false
	 *
	 */
	protected function authorizedToView()
	{
	    if ($this->user->getIsAdmin()) {
            return true;
        }        
        return false;
	}
	
    /**
     * Shows the login page
     *
     * If we don't have a user object, we show the login page.  Otherwise we forward  the user on
     * to the user home page.  
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    function processView()
    {       
        $this->getErrors();
		        
        if ($this->errorMessages) {
            $this->account = unserialize($_SESSION['account']);
        } else {
            $this->account = new Account();
        }
        
        if (!empty($_GET['aid'])) { 
            $dao = PHPARCH_DAO::singleton();
            $this->account->setAccountId($_GET['aid']);
            $this->account = $dao->get($this->account);
        }        
        
        $_SESSION['account'] = serialize($this->account);
        
        // The HTML fields already exist in the corresponding .thtml (Flexy Template) but we still
        // need to bind the field to an object.  The next series of calls achieves that.
        $this->bindObjectToFields(array('Account->firstName',
                                             'Account->lastName',
                                             'Account->userName',
                                             'Account->isAdmin',
                                             'Account->isEnabled')
                                       , $this->account);
                                       
        
        $this->setPageTitle('PHPARCH - Account Editor');
        $this->showHeader(true);
        $this->flexyHandle->compile('AccountEditor.thtml');
        $this->flexyHandle->outputObject($this, $this->flexyElements); 
        $this->showFooter();
    }
}

?>