<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Abstract class that knows how to handle active user sessions
 */
require_once 'BaseViewFlexyUser.php';

/**
 * Bring in the DAO
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Allows an administrator to maintain all look up values stored in the list_item table.
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
class PHPArch_AccountsView extends PHPARCH_BaseViewFlexyUser {
    /**
     * Holds an array of accounts that can be used by flexy to show the list of accounts
     * @var array
     * @access public
     */
    public $accounts = array();
        
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to view a screen
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can view the screen, otherwise false
	 *
	 */
	protected function authorizedToView()
	{
	    if ($this->user->getIsAdmin()) {
	        return true;
	    } else {
	        return false;
	    }
	}
	
    /**
     * Shows the account list
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    public function processView()
    {
        // Get any messages we need to show.  NOTE: the flexy template will handle showing these if
        // we got any.
        $this->getMessages();
        //print_r($_SESSION); exit;
        // Use the DAO and a named query to get all the accounts in the system.  We get back an
        // array of Propel Account objects.
        $dao = PHPARCH_DAO::singleton();
        $this->accounts = $dao->find('getAllAccounts');
        
        $this->setPageTitle('PHPARCH - System Accounts');
        $this->showHeader(true);
        $this->flexyHandle->compile('AccountList.thtml');
        $this->flexyHandle->outputObject($this);
        $this->showFooter();
    }
    
    /**
     * Determines if there are any accounts in the system.
     * 
     * This is used by flexy as it will change how it look depending on whether or not any accoutns
     * are in the system
     *
     * @author Tony Bibbs <tony@geeklog.ent>
     * @access public
     * @return int Number of accounts
     *
     */
    public function hasAccounts()
    {
        return count($this->accounts);
    }
}

?>