<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Abstract class that knows how to handle active user sessions
 */
require_once 'BaseViewFlexyUser.php';

/**
 * The Propel Account model object
 */
require_once 'PHPARCH/Contact.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Confirms the user really wants to delete an account
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
class PHPARCH_ConfirmContactDeleteView extends PHPARCH_BaseViewFlexyUser {
    /**
     * The contact the user is trying to delete
     * @var Account
     * @access public
     */
    public $contact = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * This needs to:
	 * 1) Ensure a contact ID was given
	 * 2) Ensure the contact exists
	 * 3) Ensure the user requesting to delete the contact is the true owner
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToView()
    {
        if (empty($_GET['cid'])) {
            throw new Exception('You must select a contact before trying to delete it');
        }
        
        // Load the contact
        $dao = PHPARCH_DAO::singleton();
        $this->contact = new Contact();
        $this->contact->setContactId($_GET['cid']);
        $this->contact = $dao->get($this->contact);
        
        // Make sure we got a valid contact object back.
        if (!is_object($this->contact)) {
            throw new Exception('The contact cannot be deleted because it does not exist');
        }
        
        // Ensure the contact requested is tied to the user making the request.
        if ($this->contact->getAccountId() == $this->user->getAccountId()) {
            return true;
        }
        
        return false;
    }
    
    /**
     * Confirms the user wants to delete the contact
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    function processView()
    {
        // Give the confirmation.
        $this->setPageTitle('PHPARCH - Confirm Contact Deletion');
        $this->showHeader(true);
        $this->flexyHandle->compile('ConfirmContactDeletion.thtml');
        $this->flexyHandle->outputObject($this);
        $this->showFooter();
    }
}

?>