<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Abstract class that knows how to handle active user sessions
 */
require_once 'BaseViewFlexyUser.php';

/**
 * The Contact domain object
 */
require_once 'PHPARCH/Contact.php';

/** 
 * The Address domain object
 */
require_once 'PHPARCH/Address.php';

/**
 * Allows an administrator to maintain all look up values stored in the list_item table.
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
class PHPArch_ContactEditorView extends PHPARCH_BaseViewFlexyUser {
    /**
     * Holds the contact the editor is working with.  This is made public so that 
     * flexy can work with it, if necessary.
     * @var Contact
     * @access public
     */
    public $contact = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to view a screen
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can view the screen, otherwise false
	 *
	 */
	protected function authorizedToView()
	{
	    $this->contact = new Contact(); 

	    if (empty($_GET['cid'])) return true;
	     
	    $this->contact->setContactId($_GET['cid']);
        $dao = PHPARCH_DAO::singleton();
        $this->contact = $dao->get($this->contact);
        
        // Make sure the contact is tied to the user trying to edit it.
        if ($this->contact->getAccountId() == $this->user->getAccountId()) {
            return true;
        }
        
        return false;
	}
	
    /**
     * Shows the login page
     *
     * If we don't have a user object, we show the login page.  Otherwise we forward  the user on
     * to the user home page.  
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    function processView()
    {       
        // NOTE: $this->authorizedToView() will have created the contact record for us.  All we
        // have to do here is stub out the addresses in the case we are creating a brand new 
        // contact.
        if (empty($_GET['cid'])) { 
            $this->contact->setAddressRelatedByWorkAddressId(new Address());
            $this->contact->setAddressRelatedByHomeAddressId(new Address());      
        }        
        
        $_SESSION['contact'] = serialize($this->contact);
        
        // The HTML fields already exist in the corresponding .thtml (Flexy Template) but we still
        // need to bind the field to an object.  The next series of calls achieves that.
        $this->bindObjectToFields(array('Contact->firstName',
                                             'Contact->lastName',
                                             'Contact->nickName',
                                             'Contact->primaryEmail',
                                             'Contact->SecondaryEmail',
                                             'Contact->homeNumber',
                                             'Contact->workNumber',
                                             'Contact->mobileNumber',
                                             'Contact->faxNumber',
                                             'Contact->pagerNumber',
                                             'Contact->birthDate',
                                             'Contact->internetHompage')
                                       , $this->contact);
                                       
        $wAddress = $this->contact->getAddressRelatedByWorkAddressId();
        $this->bindObjectToFields(array('Address_Work->line1',
                                             'Address_Work->line2',
                                             'Address_Work->city',
                                             'Address_Work->zipCode')
                                       , $wAddress);
                                       
        // Binding fields that use drop downs require a bit more work so we have to do them as 
        // follows
        if (is_object($wAddress)) {
            $this->getDropDown('getEnabledListItems','Address_Work->stateId',array('STATES'),
                $wAddress->getStateId(),'itemId','description','-- Select State --');
        } else {
            $this->getDropDown('getEnabledListItems','Address_Work->stateId',array('STATES'),
                '','itemId','description','-- Select State --');
        }
        
        $hAddress = $this->contact->getAddressRelatedByHomeAddressId();        
        $this->bindObjectToFields(array('Address_Home->line1',
                                             'Address_Home->line2',
                                             'Address_Home->city',
                                             'Address_Home->zipCode')
                                       , $hAddress);    
        if (is_object($hAddress)) {                                    
            $this->getDropDown('getEnabledListItems','Address_Home->stateId',array('STATES'),
                $hAddress->getStateId(),'itemId','description','-- Select State --');
        } else {
            $this->getDropDown('getEnabledListItems','Address_Home->stateId',array('STATES'),
                '','itemId','description','-- Select State --');
        }
        
        $this->setPageTitle('PHPARCH - Contact Editor');
        $this->showHeader(true);
        $this->flexyHandle->compile('ContactEditor.thtml');
        $this->flexyHandle->outputObject($this, $this->flexyElements); 
        $this->showFooter();
    }
}

?>